######
README
######

HTML Entities for Python

Motivations
###########

Drop-in replace for `python-htmlentities`_ adding: licence, Python 3 support, unit tests.

.. _python-htmlentities: https://pypi.org/project/htmlentities/
